[![image](http://img.shields.io/pypi/v/idtrackerai.svg)](https://pypi.python.org/pypi/idtrackerai/) ![pipeline](https://gitlab.com/polavieja_lab/idtrackerai/badges/master/pipeline.svg) [![Documentation Status](https://readthedocs.org/projects/idtrackerai/badge/?version=latest)](https://idtracker.ai/) [![Supported Python versions](https://img.shields.io/pypi/pyversions/idtrackerai.svg?logo=python&logoColor=FFE873)](https://pypi.org/project/idtrackerai/) ![pylint](https://gitlab.com/polavieja_lab/idtrackerai/-/jobs/artifacts/master/raw/pylint/pylint.svg?job=test) [![PyPI downloads](https://img.shields.io/pypi/dm/idtrackerai.svg)](https://pypistats.org/packages/idtrackerai) ![Licence](https://img.shields.io/gitlab/license/polavieja_lab/idtrackerai.svg)

# Find everything you are looking for in [our website](https://idtracker.ai)

Idtracker.ai is a multi-animal tracking software for laboratory conditions. This work has been published in [Nature Methods](https://doi.org/10.1038/s41592-018-0295-5) ([pdf here](https://drive.google.com/file/d/1fYBcmH6PPlwy0AQcr4D0iS2Qd-r7xU9n/view?usp=sharing))

## Installation for developers.

On an environment with Python 3.10 or 3.11 and a working installation of Pytorch (Torch and Torchvision) you can install idtracker.ai for devs by cloning the repo and installing:

``` bash
pip install git+https://gitlab.com/polavieja_lab/idtrackerai[dev,docs]
```

## Contributors
* Jordi Torrents (2022-)
* Antonio Ortega (2021-2023)
* Francisco Romero-Ferrero (2015-2022)
* Mattia G. Bergomi (2015-2018)
* Ricardo Ribeiro (2018-2020)
* Francisco J.H. Heras (2015-2022)
